function [vertex,face] = read_Allen_vtk(filename, verbose)

% read_vtk - read data from VTK file.
%
%   [vertex,face] = read_vtk(filename, verbose);
%
%   'vertex' is a 'nb.vert x 3' array specifying the position of the vertices.
%   'face' is a 'nb.face x 3' array specifying the connectivity of the mesh.
%
%   Copyright (c) Mario Richtsfeld

face = [];

if nargin<2
    verbose = 1;
end

fid = fopen(filename,'r');
if( fid==-1 )
    error('Can''t open the file.');
    return;
end

str = fgets(fid);   % -1 if eof
if ~strcmp(str(3:5), 'vtk')
    error('The file is not a valid VTK one.');    
end

%%% read header %%%
str = fgets(fid);
str = fgets(fid);
str = fgets(fid);
str = fgets(fid);
nvert = sscanf(str,'%*s %d %*s', 1);

% read vertices
[A,cnt] = fscanf(fid,'%f %f %f', 3*nvert);
if cnt~=3*nvert
    warning('Problem in reading vertices.');
end
A = reshape(A, 3, cnt/3);
vertex = A';

% read polygons
str = fgets(fid);
str = fgets(fid);

if length(str) == 1
    str = fgets(fid);
end
ntri = sscanf(str,'%*s %d %d', 1);

% read triangle strips
for x = 1:ntri
    str = fgets(fid);
    nums = sscanf(str, '%d');
    face = [face; [nums(2:(end-2)) nums(3:(end-1)) nums(4:end)]];
end
fclose(fid);

face = face + 1;

return
